# manosoba-reply-generator

## 插件功能介绍
一个可以根据输入内容生成游戏魔法少女的魔女审判回复样式图片的插件

## 安装方法
运行`nb plugin install nonebot-plugin-manosoba-reply-generator`

## 触发规则
1. /安安或/举牌可以生成安安举牌回复，加入【魔法】可更换为使用魔法时的文本颜色
2. /赞同/反驳/疑问/伪证可以生成游戏中的四种回复

## tbd
- [ ] 进行【】内的内容检测 加入部分变蓝的选项
- [ ] 多个选项合成
- [ ] 添加角色在审判时说话的回复